@@ -20,7 +20,7 @@ import monasca_agent.common.util as util
 
 # set up logging before importing any other components
 util.initialize_logging('collector')
-os.umask(022)
+os.umask(0o22)
 
 # Check we're not using an old version of Python. We need 2.4 above because
 # some modules (like subprocess) were only introduced in 2.4.
@@ -30,7 +30,6 @@ if int(sys.version_info[1]) <= 3:
 
 # Constants
 PID_NAME = "monasca-agent"
-WATCHDOG_MULTIPLIER = 10
 RESTART_INTERVAL = 4 * 24 * 60 * 60  # Defaults to 4 days
 START_COMMANDS = ['start', 'restart', 'foreground']
 
@@ -92,9 +91,7 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
 
         self.collector = checks.collector.Collector(config, monasca_agent.common.emitter.http_emitter, checksd)
 
-        # Configure the watchdog.
         check_frequency = int(config['check_freq'])
-        watchdog = self._get_watchdog(check_frequency, config)
 
         # Initialize the auto-restarter
         self.restart_interval = int(config.get('restart_interval', RESTART_INTERVAL))
@@ -102,7 +99,7 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
 
         # Run the main loop.
         while self.run_forever:
-
+            collection_start = time.time()
             # enable profiler if needed
             profiled = False
             if config.get('profile', False) and config.get('profile').lower() == 'yes':
@@ -138,9 +135,13 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
             # Only plan for the next loop if we will continue,
             # otherwise just exit quickly.
             if self.run_forever:
-                if watchdog:
-                    watchdog.reset()
-                time.sleep(check_frequency)
+                collection_time = time.time() - collection_start
+                if collection_time < check_frequency:
+                    time.sleep(check_frequency - collection_time)
+                else:
+                    log.info("Collection took {0} which is as long or longer then the configured collection frequency "
+                             "of {1}. Starting collection again without waiting in result.".format(collection_time,
+                                                                                                   check_frequency))
 
         # Now clean-up.
         try:
@@ -153,16 +154,6 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
         log.info("Exiting. Bye bye.")
         sys.exit(0)
 
-    @staticmethod
-    def _get_watchdog(check_freq, agentConfig):
-        watchdog = None
-        if agentConfig.get("watchdog", True):
-            watchdog = util.Watchdog(check_freq * WATCHDOG_MULTIPLIER,
-                                     max_mem_mb=agentConfig.get('limit_memory_consumption',
-                                                                None))
-            watchdog.reset()
-        return watchdog
-
     def _should_restart(self):
         if time.time() - self.agent_start > self.restart_interval:
             return True
@@ -264,7 +255,6 @@ def main():
             run_check(check)
 
     elif 'configcheck' == command or 'configtest' == command:
-        osname = util.get_os()
         all_valid = True
         paths = util.Paths()
         for conf_path in glob.glob(os.path.join(paths.get_confd_path(), "*.yaml")):
@@ -317,13 +307,14 @@ def main():
 
     return 0
 
+
 def run_check(check):
 
     is_multi_threaded = False
     if isinstance(check, status_checks.ServicesCheck):
         is_multi_threaded = True
     print("#" * 80)
-    print("Check name: '{}'\n".format(check.name))
+    print("Check name: '{0}'\n".format(check.name))
     check.run()
     # Sleep for a second and then run a second check to capture rate metrics
     time.sleep(1)
