@@ -15,9 +15,9 @@
 
 """Implementation of Inspector abstraction for VMware vSphere"""
 
-from oslo.config import cfg
-from oslo.utils import units
-from oslo.vmware import api
+from oslo_config import cfg
+from oslo_utils import units
+from oslo_vmware import api
 
 from monasca_agent.collector.virt import inspector as virt_inspector
 from monasca_agent.collector.virt.vmware import vsphere_operations
@@ -29,26 +29,29 @@ opt_group = cfg.OptGroup(name='vmware',
 OPTS = [
     cfg.StrOpt('host_ip',
                default='',
-               help='IP address of the VMware Vsphere host'),
+               help='IP address of the VMware Vsphere host.'),
+    cfg.IntOpt('host_port',
+               default=443,
+               help='Port of the VMware Vsphere host.'),
     cfg.StrOpt('host_username',
                default='',
-               help='Username of VMware Vsphere'),
+               help='Username of VMware Vsphere.'),
     cfg.StrOpt('host_password',
                default='',
-               help='Password of VMware Vsphere',
+               help='Password of VMware Vsphere.',
                secret=True),
     cfg.IntOpt('api_retry_count',
                default=10,
-               help='Number of times a VMware Vsphere API must be retried'),
+               help='Number of times a VMware Vsphere API may be retried.'),
     cfg.FloatOpt('task_poll_interval',
                  default=0.5,
                  help='Sleep time in seconds for polling an ongoing async '
-                      'task'),
+                      'task.'),
     cfg.StrOpt('wsdl_location',
                help='Optional vim service WSDL location '
                     'e.g http://<server>/vimService.wsdl. '
                     'Optional over-ride to default location for bug '
-                    'work-arounds'),
+                    'work-arounds.'),
 ]
 
 cfg.CONF.register_group(opt_group)
@@ -71,7 +74,8 @@ def get_api_session():
         cfg.CONF.vmware.host_password,
         cfg.CONF.vmware.api_retry_count,
         cfg.CONF.vmware.task_poll_interval,
-        wsdl_loc=cfg.CONF.vmware.wsdl_location)
+        wsdl_loc=cfg.CONF.vmware.wsdl_location,
+        port=cfg.CONF.vmware.host_port)
     return api_session
 
 
@@ -86,7 +90,7 @@ class VsphereInspector(virt_inspector.Inspector):
         vm_moid = self._ops.get_vm_moid(instance.id)
         if vm_moid is None:
             raise virt_inspector.InstanceNotFoundException(
-                _('VM %s not found in VMware Vsphere') % instance.id)
+                'VM %s not found in VMware Vsphere' % instance.id)
         cpu_util_counter_id = self._ops.get_perf_counter_id(
             VC_AVERAGE_CPU_CONSUMED_CNTR)
         cpu_util = self._ops.query_vm_aggregate_stats(
@@ -103,7 +107,7 @@ class VsphereInspector(virt_inspector.Inspector):
         vm_moid = self._ops.get_vm_moid(instance.id)
         if not vm_moid:
             raise virt_inspector.InstanceNotFoundException(
-                _('VM %s not found in VMware Vsphere') % instance.id)
+                'VM %s not found in VMware Vsphere' % instance.id)
 
         vnic_stats = {}
         vnic_ids = set()
@@ -135,7 +139,7 @@ class VsphereInspector(virt_inspector.Inspector):
         vm_moid = self._ops.get_vm_moid(instance.id)
         if vm_moid is None:
             raise virt_inspector.InstanceNotFoundException(
-                _('VM %s not found in VMware Vsphere') % instance.id)
+                'VM %s not found in VMware Vsphere' % instance.id)
         mem_counter_id = self._ops.get_perf_counter_id(
             VC_AVERAGE_MEMORY_CONSUMED_CNTR)
         memory = self._ops.query_vm_aggregate_stats(
@@ -148,7 +152,7 @@ class VsphereInspector(virt_inspector.Inspector):
         vm_moid = self._ops.get_vm_moid(instance.id)
         if not vm_moid:
             raise virt_inspector.InstanceNotFoundException(
-                _('VM %s not found in VMware Vsphere') % instance.id)
+                'VM %s not found in VMware Vsphere' % instance.id)
 
         disk_stats = {}
         disk_ids = set()
