@@ -1,9 +1,10 @@
 # stdlib
-import sys
-import time
-from datetime import datetime, timedelta
+from datetime import datetime
+from datetime import timedelta
 import logging
 from operator import attrgetter
+import sys
+import time
 
 # project
 import monasca_agent.common.check_status as check_status
@@ -116,9 +117,9 @@ class MetricTransaction(Transaction):
 
 
 class TransactionManager(util.Dimensions):
-
     """Holds any transaction derived object list and make sure they
-       are all commited, without exceeding parameters (throttling, memory consumption) """
+       are all committed, without exceeding parameters (throttling, memory consumption)
+    """
 
     def __init__(self, max_wait_for_replay, max_queue_size, throttling_delay, agent_config):
         super(TransactionManager, self).__init__(agent_config)
@@ -128,7 +129,7 @@ class TransactionManager(util.Dimensions):
 
         self._flush_without_ioloop = False  # useful for tests
 
-        self._transactions = []  # List of all non commited transactions
+        self._transactions = []  # List of all non committed transactions
         self._total_count = 0  # Maintain size/count not to recompute it everytime
         self._total_size = 0
         self._flush_count = 0
@@ -214,7 +215,7 @@ class TransactionManager(util.Dimensions):
             self._trs_to_flush = to_flush
             self.flush_next()
             # The emit time is reported on the next run.
-            dimensions = self._set_dimensions({'component': 'monasca-agent'})
+            dimensions = self._set_dimensions({'component': 'monasca-agent', 'service': 'monitoring'})
             emit_measurement = metrics.Measurement('monasca.emit_time_sec', time.time(), timer.step(), dimensions)
             MetricTransaction([emit_measurement], headers={'Content-Type': 'application/json'})
         else:
