@@ -5,8 +5,9 @@ class Ceilometer(monasca_setup.detection.ServicePlugin):
 
     """Detect Ceilometer daemons and setup configuration to monitor them."""
 
-    def __init__(self, template_dir, overwrite=True):
+    def __init__(self, template_dir, overwrite=True, args=None):
         service_params = {
+            'args': args,
             'template_dir': template_dir,
             'overwrite': overwrite,
             'service_name': 'telemetry',
