@@ -2,6 +2,7 @@ import logging
 
 import monasca_setup.agent_config
 import monasca_setup.detection
+from monasca_setup.detection.utils import find_process_name
 
 log = logging.getLogger(__name__)
 
@@ -23,7 +24,7 @@ class MySQL(monasca_setup.detection.Plugin):
         """Run detection, set self.available True if the service is detected.
 
         """
-        if monasca_setup.detection.find_process_name('mysqld') is not None:
+        if find_process_name('mysqld') is not None:
             self.available = True
 
     def build_config(self):
@@ -32,14 +33,14 @@ class MySQL(monasca_setup.detection.Plugin):
         """
         config = monasca_setup.agent_config.Plugins()
         # First watch the process
-        config.merge(monasca_setup.detection.watch_process(['mysqld']))
+        config.merge(monasca_setup.detection.watch_process(['mysqld'], 'mysql'))
         log.info("\tWatching the mysqld process.")
 
         # Attempt login, requires either an empty root password from localhost
         # or relying on a configured /root/.my.cnf
         if self.dependencies_installed():  # ensures MySQLdb is available
-            import MySQLdb
             import _mysql_exceptions
+            import MySQLdb
             try:
                 MySQLdb.connect(read_default_file=mysql_conf)
             except _mysql_exceptions.MySQLError:
@@ -57,6 +58,8 @@ class MySQL(monasca_setup.detection.Plugin):
                 try:
                     with open(mysql_conf, "r") as confFile:
                         for row in confFile:
+                            # If there are any spaces in confFile, remove them
+                            row = row.replace(" ", "")
                             if client_section:
                                 if "[" in row:
                                     break
@@ -67,7 +70,7 @@ class MySQL(monasca_setup.detection.Plugin):
                             if "[client]" in row:
                                 client_section = True
                     config['mysql'] = {'init_config': None, 'instances':
-                                       [{'server': 'localhost', 'port': 3306,
+                                       [{'name': 'localhost', 'server': 'localhost', 'port': 3306,
                                          'user': my_user, 'pass': my_pass}]}
                 except IOError:
                     log.error("\tI/O error reading {:s}".format(mysql_conf))
@@ -82,7 +85,7 @@ class MySQL(monasca_setup.detection.Plugin):
                 else:
                     log.info("\tConfiguring plugin to connect with user root.")
                     config['mysql'] = {'init_config': None, 'instances':
-                                       [{'server': 'localhost', 'user': 'root',
+                                       [{'name': 'localhost', 'server': 'localhost', 'user': 'root',
                                          'port': 3306}]}
 
         if 'mysql' not in config:
