@@ -1,10 +1,17 @@
 """ Util functions to assist in detection.
 """
-import psutil
+import logging
 import subprocess
+from subprocess import CalledProcessError
+from subprocess import PIPE
+from subprocess import Popen
+
+import psutil
 
 from monasca_setup import agent_config
-from subprocess import Popen, PIPE, CalledProcessError
+
+log = logging.getLogger(__name__)
+
 
 # check_output was introduced in python 2.7, function added
 # to accommodate python 2.6
@@ -29,9 +36,11 @@ def find_process_cmdline(search_string):
     """Simple function to search running process for one with cmdline containing.
     """
     for process in psutil.process_iter():
-        for arg in process.cmdline():
-            if arg.find(search_string) != -1:
+        try:
+            if search_string in ' '.join(process.cmdline()):
                 return process
+        except psutil.NoSuchProcess:
+            continue
 
     return None
 
@@ -40,8 +49,11 @@ def find_process_name(pname):
     """Simple function to search running process for one with pname.
     """
     for process in psutil.process_iter():
-        if pname == process.name():
-            return process
+        try:
+            if pname == process.name():
+                return process
+        except psutil.NoSuchProcess:
+            continue
 
     return None
 
@@ -53,12 +65,16 @@ def find_addr_listening_on_port(port):
             return conn.laddr[0].lstrip("::ffff:")
 
 
-def watch_process(search_strings, service=None, component=None, exact_match=True, detailed=False):
+def watch_process(search_strings, service=None, component=None,
+                  exact_match=True, detailed=False, process_name=None):
     """Takes a list of process search strings and returns a Plugins object with the config set.
         This was built as a helper as many plugins setup process watching
     """
     config = agent_config.Plugins()
-    parameters = {'name': search_strings[0],
+
+    # Fallback to default process_name strategy if process_name is not defined
+    process_name = process_name if process_name else search_strings[0]
+    parameters = {'name': process_name,
                   'detailed': detailed,
                   'exact_match': exact_match,
                   'search_string': search_strings}
@@ -72,6 +88,25 @@ def watch_process(search_strings, service=None, component=None, exact_match=True
     return config
 
 
+def watch_process_by_username(username, process_name, service=None, component=None, detailed=False):
+    """Takes a user and returns a Plugins object with the config set for a process check by user.
+        This was built as a helper as many plugins setup process watching.
+    """
+    config = agent_config.Plugins()
+
+    parameters = {'name': process_name,
+                  'detailed': detailed,
+                  'username': username}
+
+    dimensions = _get_dimensions(service, component)
+    if len(dimensions) > 0:
+        parameters['dimensions'] = dimensions
+
+    config['process'] = {'init_config': None,
+                         'instances': [parameters]}
+    return config
+
+
 def service_api_check(name, url, pattern, service=None, component=None):
     """Setup a service api to be watched by the http_check plugin.
     """
